#!/bin/bash

set -e

export PYTHONPATH=$PWD/..:$PYTHONPATH

django-admin.py test --settings=tests.settings \
  test_middleware \
  test_context_processors \
  test_helpers
